波西米亚狂想曲 (豆瓣)
Description: 波西米亚狂想曲电影简介和剧情介绍,波西米亚狂想曲影评、图片、预告片、影讯、论坛、在线购票
Keywords: 波西米亚狂想曲,Bohemian Rhapsody,波西米亚狂想曲影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.215豆瓣电影Top250

# 波西米亚狂想曲 Bohemian Rhapsody (2018)

导演: 布莱恩·辛格
编剧: 安东尼·麦卡滕 / 皮特·摩根
主演: 拉米·马雷克 / 本·哈迪 / 约瑟夫·梅泽罗 / 格威利姆·李 / 艾伦·里奇 / 露西·宝通 / 艾丹·吉伦 / 汤姆·霍兰德 / 麦克·梅尔斯 / 阿隆·麦克卡斯克 / 梅内卡·达斯 / 迪基·博 / 蒂姆· 普莱斯特 / 杰克·罗思 / 马克斯·班内特 / 基兰·哈德卡斯托 / 罗斯·格林 / 布鲁斯·麦克金伦 / 米歇尔·邓肯 / 马特·格林伍德 / 罗茜·本杰明 / 约翰·奥特曼 / 詹姆斯·华莱士 / 文森特·阿德里安 / 拉斯科·阿特金斯 / 乔纳森·奇塔姆 / 迈克尔·科布 / 耶稣·加洛 / 亚当·兰伯特 / 豪尔赫·莱昂·马丁内斯 / 杰森· 莱恩斯 / 伊斯雷尔·鲁兹
类型: 剧情 / 同性 / 音乐 / 传记
制片国家/地区: 英国 / 美国
语言: 英语
上映日期: 2019-03-22(中国大陆) / 2018-11-02(美国)
片长: 135分钟 / 131分钟(中国大陆)
又名: 波希米亚狂想曲：摇滚传说(港) / 波希米亚狂想曲(台)
IMDb: tt1727824
豆瓣评分
引用
8.6
569875人评价
5星
47.8%
4星
38.6%
3星
12.0%
2星
1.3%
1星
0.2%
好于 96% 传记片
好于 97% 音乐片
想看 看过
评价:
推荐

## 波西米亚狂想曲的剧情简介 · · · · · ·

本片是对皇后乐队、传奇主唱弗雷迪·莫库里以及他们音乐的致敬盛宴，这是一段充满爱、痛苦、接纳和音乐的旅程。
弗雷迪·莫库里（拉米·马雷克 饰）曾是希思罗机场的一名普通搬运工，对音乐满腔热血的他，与布莱恩·梅（格威利姆·李 饰）、罗杰·泰勒（本·哈迪 饰）、约 翰·迪肯（约瑟夫·梅泽罗 饰）组成皇后乐队。这个殿堂级乐队的从无到有，从疏离到重聚，从低谷到巅峰，仿佛就是弗雷迪一生的缩影。在最后的日子里，弗雷迪做了生命中最重要的决定——在音乐史上最伟大的“拯救生命”大型摇滚乐演唱会上，将所有热血付诸于歌声。 ©豆瓣

## 波西米亚狂想曲的演职员 · · · · · · ( 全部 63 )

- 布莱恩·辛格 导演
- 拉米·马雷克 饰 弗雷迪·莫库里 Freddie Mercury
- 本·哈迪 饰 罗杰·泰勒 Roger Taylor
- 约瑟夫·梅泽罗 饰 约翰·迪肯 John Deacon
- 格威利姆·李 饰 布莱恩·梅 Brian May
- 艾伦·里奇 饰 保罗·普兰特 Paul Prenter

## 波西米亚狂想曲的视频和图片 · · · · · · ( 预告片58 | 添加视频评论 | 图片1428 · 添加 )

## 波西米亚狂想曲的获奖情况 · · · · · · ( 全部 )

- 第91届奥斯卡金像奖
- 最佳影片(提名)
- 格拉汉姆·金

- 第76届金球奖
- 电影类 最佳剧情片

- 第72届英国电影学院奖
- 电影奖 最佳英国影片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  极速车王

  海上钢琴师

  倒数时刻

  社交网络

  醉乡民谣

  马戏之王

  末代皇帝

  达拉斯买家俱乐部

  汉密尔顿

  爆裂鼓手

我要写短评

## 波西米亚狂想曲的短评 · · · · · · ( 全部 167769 条 )

热门 / 最新 / 好友

### 6101 有用 赵贾森 看过 2018-11-04 03:14:03

坐在几百个白发的叔叔阿姨中间观影，感觉我们虽隔了二十多年但共享了一段青春。

### 4620 有用 小四不象 看过 2018-10-25 08:18:39

Rami Malek该拿个奥斯卡提名了，台风简直神还原。最后Live Aid拍出了那么点伟大的范儿，我特意去油管看了原视频，电影这段还原得原汁原味，高空航拍越过人山人海的观众，然后镜头直接连到主舞台钢琴下对Freddie的特写，这个合成长镜头实在太酷了！万众瞩目，集全宇宙之光于一身的感觉；开头唱到Life had just begun就开始泪崩，结合他之前跟乐队成员说出自己得了艾滋，再看Bohem... Rami Malek该拿个奥斯卡提名了，台风简直神还原。最后Live Aid拍出了那么点伟大的范儿，我特意去油管看了原视频，电影这段还原得原汁原味，高空航拍越过人山人海的观众，然后镜头直接连到主舞台钢琴下对Freddie的特写，这个合成长镜头实在太酷了！万众瞩目，集全宇宙之光于一身的感觉；开头唱到Life had just begun就开始泪崩，结合他之前跟乐队成员说出自己得了艾滋，再看Bohemian Rhapsody的歌词，感觉每一句都是重磅催泪弹，于是才明白为啥这部传记片要用这首歌名当电影名；Live Aid上演出的每分每秒，都是Freddie燃烧生命的表演，这是他传奇人生的伟大谢幕。 (展开)

### 1471 有用 糯木 看过 2018-10-29 12:04:44

前半部分剧情潦草得仿佛赶着去投胎，内心OS：这拍的什么鬼？！大皇后好不容易有个传记片求别毁啊啊啊。最后Live Aid部分神奇地力挽狂澜，OS：壮哉你大皇后，片子拍得再水都能靠歌救回来。但严肃地说，布莱恩·辛格对牙叔私生活的呈现有哗众取宠之嫌，而对他真正的音乐精神和生命力却轻描淡写，“天才巨星”整个像撞大运一样【虽然人家牙叔是这么说的，但你也不能真这么拍吧。

### 4015 有用 Peter Cat 看过 2018-12-25 07:50:58

其实也只三十年功夫，摇滚作为行动和爱的时代已经灰飞烟灭，我们究竟生活在什么样世代？

### 2720 有用 桃桃林林 看过 2018-11-08 19:01:27

作为传记片其实挺普通的，不过，结尾那段live aid 还是给煽到热泪盈眶。唉，这就是音乐的魔力吧。

> 更多短评 167769条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 波西米亚狂想曲的影评 · · · · · · ( 全部 1678 条 )

热门 / 最新 / 好友
皇家丽人 2018-11-13 21:52:48

## We Are Family — 电影《波西米亚狂想曲》的真实性大概超出了你的认知度与想象力

这篇影评可能有剧透

我们从来就只讲述真相——布莱恩·梅 和 罗杰·泰勒 一、温馨提示 在观看这部电影之前，要牢记一条：这是一部关于皇后乐队（Queen）主唱Freddie Mercury的传记电影，不是皇后乐队的传记片，也不是纪录片。Freddie是男主角，Brian May，Roger Taylor和John Deacon是打酱油的（他... (展开)
7893 85 433回应 收起
席德 2019-01-30 16:13:34 #电影《波西米亚狂想曲》与真实事件相比，有哪些异同？

## 电影角色 vs 角色原型

图多警告 本文中大部分图片为gif动图。 如果它们不动，点一下图上的△加载它。 如果发现图片已经被压缩成jpeg，说明你打开的方式不对。（[点这里在新页面打开]） 1.男主角：Freddie Mercury 虽然Malek的表演收获了许多好评，获得了金球奖最佳男主角，但其实他是四个角色中最不... (展开)
4930 36 254回应 收起
Mr.Moonlight 2018-11-08 11:05:36

## 好莱坞尽了全力，也无法复制Mercury和他的时代

这篇影评可能有剧透

1990年，Freddie Mercury的身体已经衰弱到几乎无法走路，他还在录制自己人生中最后一张专辑。 录制专辑里最后一首歌的时候，吉他手Brian担心Mercury太过虚弱无法唱出歌里的高音。在录音室里，Mercury只回了一句“I'll fucking do it, darling”，然后龇着牙喝干一大杯伏特加，... (展开)
2591 52 222回应 收起
DáDá 2019-01-19 17:31:07 #电影《波西米亚狂想曲》与真实事件相比，有哪些异同？

## 复刻摇滚传奇弗雷迪·默丘里 —— 记几场令人震撼的演唱现场

影片是对摇滚音乐史上一段传奇人物的复刻与致敬。 片名取自皇后乐队最具个性特色的歌曲《波西米亚狂想曲》。 影片重现了皇后乐队灵魂人物，主唱弗雷迪·默丘里（Freddie Mercury）神秘的人生轨迹：皇后乐队的组建、《波西米亚狂想曲》等标志性歌曲的创作过程、饱受争议的情感经... (展开)
1471 18 71回应 收起
游萦 2019-03-25 06:43:56 #电影《波西米亚狂想曲》与真实事件相比，有哪些异同？

## 我与皇后乐队——一梦十二年

严重偏题的碎碎念，慎看。 如果说有哪支乐队改变了我的人生轨迹，那一定是Queen。 14岁那年，我在老家的一家盗版音像店"十元三张"区发现了一张封面很有逼格的唱片——Queen Greatest Hits II，Queen八十年代的精选集。回到家放到碟片机里，第一首响起来的歌是《It's Kind of Ma... (展开)
887 4 64回应 收起
Mibell 2019-01-31 23:50:31 #《波西米亚狂想曲》中有哪些彩蛋？

## 《波西米亚狂想曲》中有哪些彩蛋？

这篇影评可能有剧透

文末放上⚡被误认为是彩蛋的地方~先讲彩蛋 1、电影后面live aid那段，国外细心影迷发现“DavidBowie"(以下简称宝爷)和“EltonJohn”悄悄客串了一把。 2、还有电影最开始的live aid，也是演员演的宝爷，记者还喊了声David~ 3、电影开始还说邀请到了戴安娜王妃夫妇，紧接着这段... (展开)
519 12 82回应 收起
柴斯卡 2019-03-22 14:00:21

## 我再也不整牙了

（一）整牙：Is this the real life ？Is this just fantasy ？ Freddie 是个凸嘴龅牙。《波西米亚狂想曲》中记者问他为什么不整牙，他说在英国要合群。这当然是一个玩笑。看了这段我觉得他太他妈酷了。我也是龅牙，从小到大不停有人让我整牙，久而久之我自己也觉得不整牙我就... (展开)
420 16 34回应 收起
皇家丽人 2018-04-20 19:29:14

## 今年最期待的一部电影：《波希米亚狂想曲》

转自Queen（皇后乐队）的微博（Queen_皇后乐队）及微信（QueenRockBand）：[https://weibo.com/3526028817/Gcfmi5JIs] 20世纪福斯电影公司近期宣布，原定于今年圣诞节北美上映的皇后乐队（Queen）的主唱弗雷迪·莫库里（Freddie Mercury）传记电影《波希米亚狂想曲》（Bohemian... (展开)
199 3 20回应 收起
夜第七章 2019-03-18 08:41:27 #电影《波西米亚狂想曲》与真实事件相比，有哪些异同？

## 伟大从来都在以疼痛取悦人世

一 薄伽丘在《十日谈》中讲述过诗人圭多·卡瓦尔坎蒂的故事。 卡瓦尔坎蒂喜欢在教堂的墓地里边散步边思考。佛罗伦萨的豪门子弟见他不愿与他们一起寻欢作乐，于是，骑马来到墓地里挖苦他。卡瓦尔坎蒂看见自己被包围了，说道：「你们在自己的老家里，爱怎么跟我说话就怎么说吧。... (展开)
321 4 36回应 收起
Dear deer 2019-01-29 16:24:19

## 盛名之下 其实平庸

“在这个世界上，唯一比他们的音乐更疯狂的，只有他的故事”——《波希米亚狂想曲》的预告片打出了这样的宣传语。 作为一部音乐传记片，它有着不错的观赏度，男主角Rami Malek不遗余力贴近角色的演绎，再现现场轰动效果的舞台演出，和跌宕起伏的人生历程。同时也可以轻易想象到... (展开)
177 71 106回应 收起

> 更多影评 1678篇

添加新讨论

## 讨论区 · · · · · ·

资源被封了？？为什么？？？ | 来自whereby |  | 2022-11-20 16:08:52
国内什么能拍一部beyond传记电影 | 来自一笑千金 | 11 回应 | 2022-11-13 03:40:35
白开水一样的旋律，不懂你们在共情什么，哭些什么... | 来自逗比 | 16 回应 | 2022-11-10 03:19:32
所以 这个片段怎么处理？ | 来自2han9J1a9i | 117 回应 | 2022-11-06 14:29:41
豆瓣8.8分是不是虚高了？ | 来自結 | 173 回应 | 2022-11-06 14:09:00

> 去这部影片的讨论区（全部601条）

## 关于《波西米亚狂想曲》的问题 · · · · · · ( 全部21个 )

- 最后看电视的人是谁呀？ 2人回答
- 是拉米自己唱的吗？还是用的专辑里或mv里的声音？ 2人回答

> 全部21个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- He loves a man, she loves a woman(1/2) (影志)
- {北美电影票房总排行} (荔枝超人)
- 剧情扣人、故事性强、不闷的好电影 (影志)

## 谁在看这部电影 · · · · · ·

- 再见白丝
  3分钟前 想看
- 柚子
  5分钟前 看过
- AKIRA_Funghi
  5分钟前 看过

797120人看过 / 316761人想看

订阅波西米亚狂想曲的评论:
feed: rss 2.0